#include "note.h"    // trascrive all'interno dello sketch il contenuto del file note.h
const int pinPiezo = 7;    // pin digitale al quale colleghiamo il piezo-speaker
const int pinImpulso = 8;  // pin sul quale scrive l'impulso
const int pinEco = 9;      // pin dal quale legge il tempo dopo il quale arriva l'eco 
const int pinLED = 13;     // pin al quale abbiamo collegato il LED (quello "on board")

// vettore di interi che contiene la lista delle 8 note di un'ottava completa: 
int scala[] = { NOTA_DO5, NOTA_RE5, NOTA_MI5, NOTA_FA5, NOTA_SOL5, NOTA_LA5, NOTA_SI5, NOTA_DO6 };

void setup() {
  pinMode(pinPiezo, OUTPUT);    // setta il pin come canale di output
  pinMode(pinImpulso, OUTPUT);  // setta il pin come canale di output
  pinMode(pinEco, INPUT);       // setta il pin come canale di input
  pinMode(pinLED, OUTPUT);      // setta il pin come canale di output
  Serial.begin(9600);           // inizializza la porta seriale a 9600 baud
}

void loop() {
  // dopo aver preparato una base pulita, invia un impulso di 10 microsecondi
  digitalWrite( pinImpulso, LOW );   //  
  delay(60);                         //  1                   +---------+ 
  digitalWrite( pinImpulso, HIGH );  //                      |         |
  delayMicroseconds( 10 );           //  0  -----------------+         +----------- ...
  digitalWrite( pinImpulso, LOW );   //     <---  60 ms  ---><- 10 ns ->  
  long tempo = pulseIn( pinEco, HIGH ); // legge il tempo di andata e ritorno dell'eco
  long distanza = calcolaDistanza(tempo);  // chiama la funzione per trovare la distanza

  // il primo (5) e il secondo numero (55) sono le misure osservate per il primo e 
  // l'ultimo tasto: la funzione map() trasforma così la distanza in una nota
  int nota = map(distanza, 5, 55, 0, 7);

  Serial.print(distanza);   // scrive la misura sulla seriale
  Serial.print(" cm ");

  if ((nota >= 0) && (nota <= 7)) {         // se è sopra la tastiera: 
    digitalWrite(pinLED, HIGH);             // accende il LED,
    tone(pinPiezo, scala[nota], 1000/4);    // suona la nota da un quarto
    Serial.print(" => nota ");              // e
    Serial.println(nota);                   // la scrive sulla seriale
  } 
  else {                                    // altrimenti:
    digitalWrite(pinLED, LOW);              // spegne il LED,
    noTone(pinPiezo);                       // spegne il piezo-buzzer
    Serial.println(" => fuori scala");      // e lo segnala sulla seriale
  }
}

// funzione che calcola la distanza dell'ostacolo, a partire dal tempo di volo 
long calcolaDistanza(long microsecondi) {
  // La velocità del suono è 340 m/s, quindi per coprire un cm ci vogliono 29.4 microsecondi.
  // Il ping sonoro percorre andata e ritorno, quindi per trovare la distanza dell'ostacolo
  // dobbiamo prendere la metà della distanza percorsa dal suono.
  return microsecondi / 29.4 / 2;
}
