const int pinFoto = A0; // il numero del pin analogico al quale colleghiamo la fotoresistenza
const int pinLED = 13;  // il numero del pin digitale al quale colleghiamo il LED
const int pinPiezo = 8; // il numero del pin digitale al quale colleghiamo il piezo-speaker
int valFoto;            // variabile per il valore letto dalla fotoresistenza (sta tra 0 e 1023)
int valFotoMin = 1023;  // variabile per il valore minimo letto durante la fase di calibrazione
int valFotoMax = 0;     // variabile per il valore massimo letto durante la fase di calibrazione
int nota;               // variabile per l'acutezza della nota che andremo a suonare

void setup() {
  pinMode(pinLED, OUTPUT);      // imposta il pin del LED come output
  digitalWrite(pinLED, HIGH);   // e lo accende per indicare che è iniziata la calibrazione

  while (millis() < 5000) {         // durante i primi 5 secondi dall'avvio dello sketch
    valFoto = analogRead(pinFoto);  // legge il valore della luminosità

    // controlla se questo valore è il nuovo massimo; eventualmente lo prende come nuovo massimo
    if (valFoto > valFotoMax) { valFotoMax = valFoto; }

    // controlla se questo valore è il nuovo minimo; eventualmente lo prende come nuovo minimo
    if (valFoto < valFotoMin) { valFotoMin = valFoto; }
  }

  digitalWrite(pinLED, LOW);    // spegne il LED per indicare che è finita la calibrazione
}

void loop() {
  valFoto = analogRead(pinFoto);    // legge il valore della luminosità

  // trasforma valFoto (che sappiamo variare tra valFotoMin e valFotoMax) in un numero 
  // compreso tra 50 e 4000: l'acutezza delle note riprodotte sarà in questo intervallo
  nota = map(valFoto, valFotoMin, valFotoMax, 50, 4000); 

  tone(pinPiezo, nota, 20); // per 20 millisecondi suona la nota sul pin del piezo-speaker

  delay(10);                // attende un poco
}

