const int pinImpulso = 8;  // pin sul quale scrive l'impulso
const int pinEco = 9;      // pin dal quale legge il tempo dopo il quale arriva l'eco 
const int pinLED = 13;     // pin al quale abbiamo collegato il LED (quello "on board")

void setup() {
  pinMode(pinImpulso, OUTPUT);  // setta il pin come canale di output
  pinMode(pinEco, INPUT);       // setta il pin come canale di input
  pinMode(pinLED, OUTPUT);      // setta il pin come canale di output
  Serial.begin(9600);           // inizializza la porta seriale a 9600 baud
}

void loop() {
  // dopo aver preparato una base pulita, invia un impulso di 10 microsecondi
  digitalWrite( pinImpulso, LOW );   //  
  delay(60);                         //  1                   +---------+ 
  digitalWrite( pinImpulso, HIGH );  //                      |         |
  delayMicroseconds( 10 );           //  0  -----------------+         +----------- ...
  digitalWrite( pinImpulso, LOW );   //     <---  60 ms  ---><- 10 ns ->  

  long tempo = pulseIn( pinEco, HIGH ); // legge il tempo di andata e ritorno dell'eco

  long distanza = calcolaDistanza(tempo);  // chiama la funzione per trovare la distanza

  Serial.print(distanza);   // scrive la misura sulla seriale
  Serial.println(" cm");

  digitalWrite(pinLED, (distanza < 10) ? HIGH : LOW); // se è vicino, accendiamo il LED
}

// funzione che calcola la distanza dell'ostacolo, a partire dal tempo di volo 
long calcolaDistanza(long microsecondi) {
  // La velocità del suono è 340 m/s, quindi per coprire un cm ci vogliono 29.4 microsecondi.
  // Il ping sonoro percorre andata e ritorno, quindi per trovare la distanza dell'ostacolo
  // dobbiamo prendere la metà della distanza percorsa dal suono.
  return microsecondi / 29.4 / 2;
}
